==> links_0.84.orig.tar.gz: links-0.84.orig/setup.h <==
#define VERSION_STRING			VERSION

#define DEBUG
#define LEAK_DEBUG
/*
#define MAX_DEBUG_SIZE			100000
#define MAX_LIST_SIZE			100000
*/

/*#define SPECIAL_MALLOC*/
#define SMALL_MALLOC			0x800
#define CHUNK_SIZE			0x10000
#define MIN_CHUNK_FREE			0x6000

#define DNS_TIMEOUT			3600000UL

#define HTTP_KEEPALIVE_TIMEOUT		60000
#define FTP_KEEPALIVE_TIMEOUT		600000
#define MAX_KEEPALIVE_CONNECTIONS	30
#define KEEPALIVE_CHECK_TIME		20000

#define MAX_REDIRECTS			10

#define MEMORY_CACHE_GC_PERCENT		9/10

#define COL(x)				((x)*0x100)

#define MAX_HISTORY_ITEMS		256
#define MENU_HOTKEY_SPACE		2

#define COLOR_MENU			COL(070)
#define COLOR_MENU_FRAME		COL(070)
#define COLOR_MENU_SELECTED		COL(007)
#define COLOR_MENU_HOTKEY		COL(007)

#define COLOR_MAINMENU			COL(070)
#define COLOR_MAINMENU_SELECTED		COL(007)
#define COLOR_MAINMENU_HOTKEY		COL(070)

#define COLOR_DIALOG			COL(070)
#define COLOR_DIALOG_FRAME		COL(070)
#define COLOR_DIALOG_TITLE		COL(007)
#define COLOR_DIALOG_TEXT		COL(070)
#define COLOR_DIALOG_CHECKBOX		COL(070)
#define COLOR_DIALOG_CHECKBOX_TEXT	COL(070)
#define COLOR_DIALOG_BUTTON		COL(070)
#define COLOR_DIALOG_BUTTON_SELECTED	COL(0107)
#define COLOR_DIALOG_FIELD		COL(007)
#define COLOR_DIALOG_FIELD_TEXT		COL(007)
#define COLOR_DIALOG_METER		COL(007)

#define SCROLL_ITEMS			2

#define DIALOG_LEFT_BORDER		3
#define DIALOG_TOP_BORDER		1
#define DIALOG_LEFT_INNER_BORDER	2
#define DIALOG_TOP_INNER_BORDER		0
#define DIALOG_FRAME			2

#define DIALOG_LB	(DIALOG_LEFT_BORDER + DIALOG_LEFT_INNER_BORDER + 1)
#define DIALOG_TB	(DIALOG_TOP_BORDER + DIALOG_TOP_INNER_BORDER + 1)

#define COLOR_TITLE			COL(007)
#define COLOR_TITLE_BG			COL(007)
#define COLOR_STATUS			COL(070)
#define COLOR_STATUS_BG			COL(007)

#define ESC_TIMEOUT			100

#define DISPLAY_TIME_MIN		200
#define DISPLAY_TIME			20

#define HTML_LEFT_MARGIN		3
#define HTML_MAX_TABLE_LEVEL		10
#define HTML_CHAR_WIDTH			7
#define HTML_CHAR_HEIGHT		12
#define HTML_TABLE_2ND_PASS
#define HTML_DEFAULT_INPUT_SIZE		20

#define MAX_INPUT_URL_LEN		4096

#define SPD_DISP_TIME			100
#define CURRENT_SPD_SEC			50
#define CURRENT_SPD_AFTER		100

#define RESOURCE_INFO_REFRESH		100

#define DOWN_DLG_MIN			20

==> links-0.92.tar.gz: links-0.92/setup.h <==
#if 0
#define VERSION_STRING			VERSION " ["__DATE__ " " __TIME__"]"
#else
#define VERSION_STRING			VERSION
#endif

#define DEBUG
#define LEAK_DEBUG
#define LEAK_DEBUG_LIST

#define LINKS_MANUAL_URL		"http://links.sourceforge.net/docs/manual-0.90-en/"

#define LINKS_SOCK_NAME			"socket"
#define LINKS_PORT			23456
#define MAX_BIND_TRIES			3

#define DNS_TIMEOUT			3600000UL

#define HTTP_KEEPALIVE_TIMEOUT		60000
#define FTP_KEEPALIVE_TIMEOUT		600000
#define MAX_KEEPALIVE_CONNECTIONS	30
#define KEEPALIVE_CHECK_TIME		20000

#define MAX_REDIRECTS			10

#define MEMORY_CACHE_GC_PERCENT		9/10
#define MAX_CACHED_OBJECT		1/4

#define MAX_HISTORY_ITEMS		256
#define MENU_HOTKEY_SPACE		2

#define COL(x)				((x)*0x100)

#define COLOR_MENU			COL(070)
#define COLOR_MENU_FRAME		COL(070)
#define COLOR_MENU_SELECTED		COL(007)
#define COLOR_MENU_HOTKEY		COL(007)

#define COLOR_MAINMENU			COL(070)
#define COLOR_MAINMENU_SELECTED		COL(007)
#define COLOR_MAINMENU_HOTKEY		COL(070)

#define COLOR_DIALOG			COL(070)
#define COLOR_DIALOG_FRAME		COL(070)
#define COLOR_DIALOG_TITLE		COL(007)
#define COLOR_DIALOG_TEXT		COL(070)
#define COLOR_DIALOG_CHECKBOX		COL(070)
#define COLOR_DIALOG_CHECKBOX_TEXT	COL(070)
#define COLOR_DIALOG_BUTTON		COL(070)
#define COLOR_DIALOG_BUTTON_SELECTED	COL(0107)
#define COLOR_DIALOG_FIELD		COL(007)
#define COLOR_DIALOG_FIELD_TEXT		COL(007)
#define COLOR_DIALOG_METER		COL(007)

#define SCROLL_ITEMS			2

#define DIALOG_LEFT_BORDER		3
#define DIALOG_TOP_BORDER		1
#define DIALOG_LEFT_INNER_BORDER	2
#define DIALOG_TOP_INNER_BORDER		0
#define DIALOG_FRAME			2

#define DIALOG_LB	(DIALOG_LEFT_BORDER + DIALOG_LEFT_INNER_BORDER + 1)
#define DIALOG_TB	(DIALOG_TOP_BORDER + DIALOG_TOP_INNER_BORDER + 1)

#define COLOR_TITLE			COL(007)
#define COLOR_TITLE_BG			COL(007)
#define COLOR_STATUS			COL(070)
#define COLOR_STATUS_BG			COL(007)

#define ESC_TIMEOUT			100

#define DISPLAY_TIME_MIN		200
#define DISPLAY_TIME			20

#define HTML_LEFT_MARGIN		3
#define HTML_MAX_TABLE_LEVEL		10
#define HTML_MAX_FRAME_DEPTH		5
#define HTML_CHAR_WIDTH			7
#define HTML_CHAR_HEIGHT		12
#define HTML_FRAME_CHAR_WIDTH		10
#define HTML_FRAME_CHAR_HEIGHT		16
#define HTML_TABLE_2ND_PASS
#define HTML_DEFAULT_INPUT_SIZE		20

#define MAX_INPUT_URL_LEN		4096

#define SPD_DISP_TIME			100
#define CURRENT_SPD_SEC			50
#define CURRENT_SPD_AFTER		100

#define RESOURCE_INFO_REFRESH		100

#define DOWN_DLG_MIN			20
